@@ -4,14 +4,14 @@ from ckan.logic.schema import validator_args
 @validator_args
 def relation_create(not_empty, one_of, ignore_missing):
     return {
-        'subject_id': [
+        "subject_id": [
             not_empty,
         ],
-        'object_id': [
+        "object_id": [
             not_empty,
         ],
-        'relation_type': [
-            one_of(['related_to', 'child_of', 'parent_of']),
+        "relation_type": [
+            one_of(["related_to", "child_of", "parent_of"]),
         ],
     }
 
@@ -19,15 +19,15 @@ def relation_create(not_empty, one_of, ignore_missing):
 @validator_args
 def relation_delete(not_empty, one_of, ignore_missing):
     return {
-        'subject_id': [
+        "subject_id": [
             not_empty,
         ],
-        'object_id': [
+        "object_id": [
             not_empty,
         ],
-        'relation_type': [
+        "relation_type": [
             ignore_missing,
-            one_of(['related_to', 'child_of', 'parent_of']),
+            one_of(["related_to", "child_of", "parent_of"]),
         ],
     }
 
@@ -35,19 +35,19 @@ def relation_delete(not_empty, one_of, ignore_missing):
 @validator_args
 def relations_list(not_empty, one_of, ignore_missing):
     return {
-        'subject_id': [
+        "subject_id": [
             not_empty,
         ],
-        'object_entity': [
+        "object_entity": [
             ignore_missing,
-            one_of(['package', 'organization', 'group']),
+            one_of(["package", "organization", "group"]),
         ],
-        'object_type': [
+        "object_type": [
             ignore_missing,
         ],
-        'relation_type': [
+        "relation_type": [
             ignore_missing,
-            one_of(['related_to', 'child_of', 'parent_of']),
+            one_of(["related_to", "child_of", "parent_of"]),
         ],
     }
 
@@ -55,19 +55,19 @@ def relations_list(not_empty, one_of, ignore_missing):
 @validator_args
 def relations_ids_list(not_empty, one_of, ignore_missing):
     return {
-        'subject_id': [
+        "subject_id": [
             not_empty,
         ],
-        'object_entity': [
+        "object_entity": [
             ignore_missing,
-            one_of(['package', 'organization', 'group']),
+            one_of(["package", "organization", "group"]),
         ],
-        'object_type': [
+        "object_type": [
             ignore_missing,
         ],
-        'relation_type': [
+        "relation_type": [
             ignore_missing,
-            one_of(['related_to', 'child_of', 'parent_of']),
+            one_of(["related_to", "child_of", "parent_of"]),
         ],
     }
 
@@ -75,11 +75,11 @@ def relations_ids_list(not_empty, one_of, ignore_missing):
 @validator_args
 def get_entity_list(not_empty, one_of, ignore_missing):
     return {
-        'entity': [
+        "entity": [
             not_empty,
-            one_of(['package', 'organization', 'group']),
+            one_of(["package", "organization", "group"]),
         ],
-        'entity_type': [
+        "entity_type": [
             not_empty,
         ],
     }
